@@ -19,7 +19,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-/* $Id: get_audio.c,v 1.125 2008/04/28 20:32:57 robert Exp $ */
+/* $Id: get_audio.c,v 1.125.2.2 2009/01/18 15:44:28 robert Exp $ */
 
 
 #ifdef HAVE_CONFIG_H
@@ -82,9 +82,10 @@ typedef struct get_audio_global_data {
     int     pcm_is_unsigned_8bit;
     unsigned int num_samples_read;
     FILE   *musicin;
+    hip_t   hip;
 } get_audio_global_data;
 
-static get_audio_global_data global = { 0, 0, 0, 0, 0, 0 };
+static get_audio_global_data global = { 0, 0, 0, 0, 0, 0, 0 };
 
 
 
@@ -1039,9 +1040,9 @@ static int const IFF_ID_COMM = 0x434f4d4d; /* "COMM" */
 static int const IFF_ID_SSND = 0x53534e44; /* "SSND" */
 static int const IFF_ID_MPEG = 0x4d504547; /* "MPEG" */
 
-static int const IFF_ID_NONE = 0x4e4f4e45; /* "NONE" *//* AIFF-C data format */
-static int const IFF_ID_2CBE = 0x74776f73; /* "twos" *//* AIFF-C data format */
-static int const IFF_ID_2CLE = 0x736f7774; /* "sowt" *//* AIFF-C data format */
+static int const IFF_ID_NONE = 0x4e4f4e45; /* "NONE" */ /* AIFF-C data format */
+static int const IFF_ID_2CBE = 0x74776f73; /* "twos" */ /* AIFF-C data format */
+static int const IFF_ID_2CLE = 0x736f7774; /* "sowt" */ /* AIFF-C data format */
 
 static int const WAV_ID_RIFF = 0x52494646; /* "RIFF" */
 static int const WAV_ID_WAVE = 0x57415645; /* "WAVE" */
@@ -1624,7 +1625,10 @@ lame_decode_initfile(FILE * fd, mp3data_struct * mp3data, int *enc_delay, int *e
     int     freeformat = 0;
 
     memset(mp3data, 0, sizeof(mp3data_struct));
-    lame_decode_init();
+    if (global.hip) {
+        hip_decode_exit(global.hip);
+    }
+    global.hip = hip_decode_init();
 
     len = 4;
     if (fread(buf, 1, len, fd) != len)
@@ -1684,7 +1688,7 @@ lame_decode_initfile(FILE * fd, mp3data_struct * mp3data, int *enc_delay, int *e
     /* so mp3data->bitrate will be 0 until we have decoded the first */
     /* frame.  Cannot decode first frame here because we are not */
     /* yet prepared to handle the output. */
-    ret = lame_decode1_headersB(buf, len, pcm_l, pcm_r, mp3data, enc_delay, enc_padding);
+    ret = hip_decode1_headersB(global.hip, buf, len, pcm_l, pcm_r, mp3data, enc_delay, enc_padding);
     if (-1 == ret)
         return -1;
 
@@ -1693,7 +1697,7 @@ lame_decode_initfile(FILE * fd, mp3data_struct * mp3data, int *enc_delay, int *e
         len = fread(buf, 1, sizeof(buf), fd);
         if (len != sizeof(buf))
             return -1;
-        ret = lame_decode1_headersB(buf, len, pcm_l, pcm_r, mp3data, enc_delay, enc_padding);
+        ret = hip_decode1_headersB(global.hip, buf, len, pcm_l, pcm_r, mp3data, enc_delay, enc_padding);
         if (-1 == ret)
             return -1;
     }
@@ -1748,7 +1752,7 @@ lame_decode_fromfile(FILE * fd, short pcm_l[], short pcm_r[], mp3data_struct * m
     unsigned char buf[1024];
 
     /* first see if we still have data buffered in the decoder: */
-    ret = lame_decode1_headers(buf, len, pcm_l, pcm_r, mp3data);
+    ret = hip_decode1_headers(global.hip, buf, len, pcm_l, pcm_r, mp3data);
     if (ret != 0)
         return ret;
 
@@ -1758,17 +1762,19 @@ lame_decode_fromfile(FILE * fd, short pcm_l[], short pcm_r[], mp3data_struct * m
         len = fread(buf, 1, 1024, fd);
         if (len == 0) {
             /* we are done reading the file, but check for buffered data */
-            ret = lame_decode1_headers(buf, len, pcm_l, pcm_r, mp3data);
+            ret = hip_decode1_headers(global.hip, buf, len, pcm_l, pcm_r, mp3data);
             if (ret <= 0) {
-                lame_decode_exit(); /* release mp3decoder memory */
+                hip_decode_exit(global.hip); /* release mp3decoder memory */
+                global.hip = 0;
                 return -1; /* done with file */
             }
             break;
         }
 
-        ret = lame_decode1_headers(buf, len, pcm_l, pcm_r, mp3data);
+        ret = hip_decode1_headers(global.hip, buf, len, pcm_l, pcm_r, mp3data);
         if (ret == -1) {
-            lame_decode_exit(); /* release mp3decoder memory */
+            hip_decode_exit(global.hip); /* release mp3decoder memory */
+            global.hip = 0;
             return -1;
         }
         if (ret > 0)
