@@ -4,7 +4,7 @@
  * Copyright (c) 1999 Mark Taylor
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2 of the License, or (at your option) any later version.
  *
@@ -13,7 +13,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
  * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
@@ -22,14 +22,7 @@
 #ifndef LAME_VBRQUANTIZE_H
 #define LAME_VBRQUANTIZE_H
 
-int VBR_noise_shaping(
-                    lame_internal_flags * gfc,
-                    FLOAT8            * xr34orig, 
-                    int                 minbits, 
-                    int                 maxbits,
-                    FLOAT8	      * l3_xmin,
-                    int                 gr,
-                    int                 ch );
+int     VBR_encode_frame(lame_internal_flags * gfc, FLOAT xr34orig[2][2][576],
+                         FLOAT l3_xmin[2][2][SFBMAX], int maxbits[2][2]);
 
 #endif /* LAME_VBRQUANTIZE_H */
-
